# OpenStack's Python CLI

OpenStack provides a Python SDK that simplifies interactions with OpenStack cloud services. This tutorial will guide you through the installation of the SDK, creating a connection to your OpenStack cloud, and managing virtual machines (VMs) using the Python CLI.

## Installation

To get started, you need to install the OpenStack SDK. This can be done easily with `pip`, the Python package installer. Run the following command in your terminal:

```bash
pip install openstacksdk
```

This command fetches the OpenStack SDK from the Python Package Index (PyPI) and installs it on your system.

## Creating a connection

Once the SDK is installed, you can establish a connection to your OpenStack cloud. You can do this using a single line of code if your environment is set up correctly, or you can specify all the necessary parameters explicitly. Here's how you can create a connection:

```python
conn = openstack.connect(engine='engines')

# or

conn = openstack.connect(
        auth_url="https://keystone.cloud.switch.ch:5000/v3",
        project_name="<YOUR PROJECT NAME>",
        username="<YOUR USERNAME>",
        password="<YOUR PASSWORD>",
        region_name="ZH",
        domain_name='default',
        version='2'
    )
```

In the first example, `engine='engines'` assumes that you have your cloud configuration defined in an environment variable or a configuration file. In the second example, you are explicitly providing the authentication URL, project name, username, password, region name, and other parameters needed for the connection.

Make sure to replace `<YOUR PROJECT NAME>`, `<YOUR USERNAME>`, and `<YOUR PASSWORD>` with your actual credentials. This connection will allow you to interact with various OpenStack services.

## VM Management

After establishing a connection, you can manage virtual machines in your OpenStack environment. Below is an example of how to create a new VM:

```python
server = conn.compute.create_server(
    name='Openstack-Instance',
    image_id='856becdd-3df9-488e-af98-871b98624b2c', # From: https://engines.switch.ch/horizon/project/images
    flavor_id='2', # 2 = m1.small. Use: openstack --os-cloud <cloud-name/normally is engines> flavor list
    networks=[{"uuid": 'c34c17a4-341e-463e-ab52-eed4817387ad'}] # From: https://engines.switch.ch/horizon/project/networks/, select the network you want to use, and retrieve the ID
)
```

In this code snippet:

- `name` specifies the name of the VM you want to create.
- `image_id` is the identifier for the image you want to use; you can find available images in your OpenStack dashboard under the images section.
- `flavor_id` refers to the VM flavor, which determines the resources allocated to the VM. You can list available flavors by using the OpenStack CLI command.
- `networks` is a list of networks that the VM will connect to, specified by their UUIDs, which can also be found in the OpenStack dashboard.

Once the server is created, you may want to delete it later. Here’s how you can do that:

```python
conn.compute.delete_server(server)
```

This line of code will delete the VM you created earlier. Make sure to manage your resources effectively to avoid unnecessary charges.

With this setup, you can start using the OpenStack Python SDK to automate your cloud infrastructure management tasks.

To find out more about OpenStack's Python SDK, visit [this page](https://docs.openstack.org/openstacksdk/latest/user/index.html).